@@ -210,12 +210,6 @@ class PlaywrightMiddleware(object):
         if playwright_meta.get('pretend') is not None:
             # get local pretend setting to overwrite global
             _pretend = playwright_meta.get('pretend')
-        # if _pretend:
-        #     options['ignoreDefaultArgs'] = [
-        #         '--enable-automation'
-        #     ]
-        #     options['args'].append(
-        #         '--disable-blink-features=AutomationControlled')
 
         # set proxy and proxy credential
         _proxy = self.proxy
@@ -296,7 +290,6 @@ class PlaywrightMiddleware(object):
         _timeout = self.download_timeout
         if playwright_meta.get('timeout') is not None:
             _timeout = playwright_meta.get('timeout')
-        logger.debug('timeout %s', _timeout)
         # timeout is `ms` instead of `s`, so need to multiply 1000
         page.set_default_timeout(_timeout * 1000)
 
